Learn R Programming

lavaan (version 0.7-2)

lavMatrixRepresentation: lavaan matrix representation

Description

Extend the parameter table with a matrix representation.

Usage

lavMatrixRepresentation(partable, representation = "LISREL",
                        allow_composites = TRUE,
                        add_attributes = FALSE, as_data_frame = TRUE, ...)

Value

A list or a data.frame containing the original parameter table, plus three columns: a "mat" column containing matrix names, and a "row" and "col" column for the row and column indices of the model parameters in the model matrices.

Arguments

partable

A lavaan parameter table (as extracted by the parTable function, or generated by the lavParTable function).

representation

Character. The matrix representation style. Currently, only the all-y version of the LISREL representation is supported.

allow_composites

Logical. If TRUE, and the model syntax contains the "<~" operator, handle the lhs as proper composites. If FALSE, use the old (<0.6-20) approach.

add_attributes

Logical. If TRUE, additional information about the model matrix representation is added as attributes.

as_data_frame

Logical. If TRUE, the extended parameter table is returned as a data.frame.

...

Used only to support old argument names.

See Also

lavParTable, parTable

Examples

Run this code
HS.model <- ' visual  =~ x1 + x2 + x3
              textual =~ x4 + x5 + x6
              speed   =~ x7 + x8 + x9 '

fit <- cfa(HS.model, data=HolzingerSwineford1939)

# extract partable
partable <- parTable(fit)

# add matrix representation (and show only a few columns)
lavMatrixRepresentation(partable)[,c("lhs","op","rhs","mat","row","col")]

Run the code above in your browser using DataLab