Parameter estimates of a latent variable model.
lavParameterEstimates(object,
se = TRUE, zstat = TRUE, pvalue = TRUE, ci = TRUE,
standardized = FALSE,
fmi = FALSE, plabel = FALSE,
level = 0.95, boot_ci_type = "perc",
cov_std = TRUE, fmi_options = list(),
rsquare = FALSE,
remove_system_eq = TRUE, remove_eq = TRUE,
remove_ineq = TRUE, remove_def = FALSE,
remove_nonfree = FALSE, remove_step1 = TRUE,
remove_unused = FALSE,
remove_aux = TRUE, add_attributes = FALSE,
output = "data.frame", header = FALSE, ...)
parameterEstimates(object,
se = TRUE, zstat = TRUE, pvalue = TRUE, ci = TRUE,
standardized = FALSE,
fmi = FALSE, plabel = FALSE,
level = 0.95, boot_ci_type = "perc",
cov_std = TRUE, fmi_options = list(),
rsquare = FALSE,
remove_system_eq = TRUE, remove_eq = TRUE,
remove_ineq = TRUE, remove_def = FALSE,
remove_nonfree = FALSE, remove_step1 = TRUE,
remove_unused = FALSE,
remove_aux = TRUE, add_attributes = FALSE,
output = "data.frame", header = FALSE, ...)A data.frame containing the estimated parameters, standard errors, and (by default) z-values, p-values, and the lower and upper values of the confidence intervals. If requested, extra columns are added with standardized versions of the parameter estimates.
If the model was fitted with se = "bootstrap" and
boot_ci_type = "bca", the empirical-influence design matrix used to
compute the acceleration constant is stored as the "design"
attribute of the returned data.frame (retrieve with
attr(x, "design")). The parameter estimates in the bootstrap samples
themselves are available via lavInspect(object, "coef.boot").
An object of class lavaan.
Logical. If TRUE, include column containing the standard
errors. If FALSE, this implies that zstat, pvalue, and
ci are also FALSE.
Logical. If TRUE, an extra column is added containing
the so-called z-statistic, which is simply the value of the estimate divided
by its standard error.
Logical. If TRUE, an extra column is added containing
the pvalues corresponding to the z-statistic, evaluated under a standard
normal distribution.
If TRUE, confidence intervals are added to the output.
The confidence level required.
Logical. If TRUE, show the plabel column of the
parameter table in the output.
If bootstrapping was used, the type of interval required.
The value should be one of "norm", "basic", "perc",
or "bca.simple". For the first three options, see the help page of
the boot.ci function in the boot package. The
"bca.simple" option produces intervals using the adjusted bootstrap
percentile (BCa) method, but with no correction for acceleration (only for
bias). Note that the p-value is still computed assuming that the z-statistic
follows a standard normal distribution.
Logical or character. If TRUE, standardized estimates
are added to the output. Note that SEs and tests are still based on
unstandardized estimates. Use standardizedSolution to obtain
SEs and test statistics for standardized estimates. If a character
vector is passed with any of c("std.lv","std.all","std.nox"), only the
selected standardization methods are added. Note that "std.nox" only
differs from "std.all" if fixed.x = TRUE; if
fixed.x = FALSE, the exogenous covariates are treated as random
variables (and standardized) just like any other variable, and a warning
is issued. Alternatively, a character vector
of (observed) variable names may be passed (for example
standardized = c("x1", "x2")); in that case only the parameters
involving these variables are standardized (the other observed variables are
left unstandardized), and the result is added in a std.user column.
This is a generalization of "std.nox", where the (observed) exogenous
x variables are the ones left unstandardized.
Logical. If TRUE, the (residual) observed covariances are scaled by the square root of the `Theta' diagonal elements, and the (residual) latent covariances are scaled by the square root of the `Psi' diagonal elements. If FALSE, the (residual) observed covariances are scaled by the square root of the diagonal elements of the observed model-implied covariance matrix (Sigma), and the (residual) latent covariances are scaled by the square root of diagonal elements of the model-implied covariance matrix of the latent variables.
Logical. If TRUE, an extra column is added containing the
fraction of missing information for each estimated parameter. Only
available if
estimator="ML", missing="(fi)ml", and se="standard".
See references for more information.
List. If non-empty, arguments can be provided to alter the default options when the model is fitted with the complete(d) data; otherwise, the same options are used as the original model.
Logical. If TRUE, filter the output by removing all
rows containing user-specified equality constraints, if any.
Logical. If TRUE, filter the output by
removing all rows containing system-generated equality constraints, if any.
Logical. If TRUE, filter the output by removing all
rows containing inequality constraints, if any.
Logical. If TRUE, filter the output by removing all
rows containing parameter definitions, if any.
Logical. If TRUE, filter the output by removing
all rows containing fixed (non-free) parameters.
Logical. Only used by sam().
If TRUE, filter the
output by removing all rows corresponding to the measurement parameters
that are part of the first step.
Logical. If TRUE, filter the output by removing
all rows containing automatically added parameters (user == 0) that are
nonfree, and with their final (est) values fixed to their default values
(typically 1 or 0); currently only used for intercepts and
scaling-factors.
Logical. If TRUE (the default), filter the output by
removing all rows corresponding to auxiliary (aux=) variables that were
added to the model as saturated correlates (only relevant when
missing = "ml" and the aux= argument was used).
Logical. If TRUE, add additional rows containing
the rsquare values (in the est column) of all endogenous variables
in the model. Both the lhs and rhs column contain the
name of the endogenous variable, while the op column contains r2,
to indicate that the values in the est column are rsquare values.
Deprecated argument. Please use output= instead.
Character. If "data.frame", the parameter table is
displayed as a standard (albeit lavaan-formatted) data.frame.
If "text" (or alias "pretty"), the parameter table is
formatted and displayed with subsections (as used by the summary function).
Logical. Only used if output = "text". If
TRUE, print a header at the top of the parameter list. This header
contains information about the information matrix, whether the saturated (h1)
model is structured or unstructured, and which type of standard errors are
shown in the output.
to support old argument names
Savalei, V. & Rhemtulla, M. (2012). On obtaining estimates of the fraction of missing information from FIML. Structural Equation Modeling: A Multidisciplinary Journal, 19(3), 477-494.
HS.model <- ' visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9 '
fit <- cfa(HS.model, data=HolzingerSwineford1939)
lavParameterEstimates(fit)
lavParameterEstimates(fit, output = "text")
Run the code above in your browser using DataLab