Learn R Programming

lavaan (version 0.7-2)

lavScores: Extract Empirical Estimating Functions

Description

A function for extracting the empirical estimating functions of a fitted lavaan model. This is the derivative of the objective function with respect to the parameter vector, evaluated at the observed (case-wise) data. In other words, this function returns the case-wise scores, evaluated at the fitted model parameters.

Usage

estfun.lavaan(object, scaling = FALSE, ignore_constraints = FALSE,
              remove_duplicated = TRUE, remove_empty_cases = TRUE, ...)
lavScores(object, scaling = FALSE, ignore_constraints = FALSE,
          remove_duplicated = TRUE, remove_empty_cases = TRUE, ...)

Value

A n x k matrix corresponding to n observations and k parameters.

Arguments

object

An object of class lavaan.

scaling

Only used for the ML estimator. If TRUE, the scores are scaled to reflect the specific objective function used by lavaan. If FALSE (the default), the objective function is the loglikelihood function assuming multivariate normality.

ignore_constraints

Logical. If TRUE, the scores do not reflect the (equality or inequality) constraints. If FALSE, the scores are computed by taking the unconstrained scores, and adding the term t(R) lambda, where lambda are the (case-wise) Lagrange Multipliers, and R is the Jacobian of the constraint function. Only in the latter case will the sum of the columns be (almost) equal to zero.

remove_duplicated

If TRUE, and all the equality constraints have a simple form (e.g., a == b), the unconstrained scores are post-multiplied with a transformation matrix in order to remove the duplicated parameters.

remove_empty_cases

If TRUE, empty cases with only missing values will be removed from the output.

...

To accept old argument names with dots. No other arguments are accepted.

Author

Ed Merkle for the ML case; the remove.duplicated, ignore.constraints and remove.empty.cases arguments were added by Yves Rosseel; Franz Classe for the WLS case; Yves Rosseel for the PML case.

Details

Casewise scores are available for the ML, GLS, ULS and WLS estimators, and (since 0.7-1) for the PML (pairwise maximum likelihood) estimator. For PML, the scores are the casewise derivatives of the pairwise log-likelihood (including the weighted univariate part when missing = "available.cases"); missing = "doubly.robust" is not supported (yet). Exogenous covariates (conditional.x = TRUE) are supported for PML only.

Examples

Run this code
## The famous Holzinger and Swineford (1939) example
HS.model <- ' visual  =~ x1 + x2 + x3
              textual =~ x4 + x5 + x6
              speed   =~ x7 + x8 + x9 '

fit <- cfa(HS.model, data = HolzingerSwineford1939)
head(lavScores(fit))

Run the code above in your browser using DataLab