| lavTest | R Documentation |
Compute a variety of test statistics evaluating the global fit of the model.
lavTest(lavobject, test = "standard", scaled_test = "standard",
output = "list", drop_list_single = TRUE, ...)
lavobject |
An object of class |
test |
Character vector. Multiple names of test statistics can be provided.
If |
scaled_test |
Character. Choose the test statistic
that will be scaled (if a scaled test statistic is requested).
The default is |
output |
Character. If |
drop_list_single |
Logical. Only used when |
... |
To support old argument names. |
If output = "list": a nested list with test statistics, or if
only a single test statistic is requested (and
drop_list_single = TRUE), a list with details for this test
statistic. If output = "text": the text is printed, and a
nested list of test statistics (including an info attribute) is
returned.
Hayakawa, K. (2019). Corrected goodness-of-fit test in covariance structure analysis. Psychological Methods, 24(3), 371–389. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1037/met0000180")}
Himeno, T., & Yamada, T. (2014). Estimations for some functions of covariance matrix in high dimension under non-normality and its applications. Journal of Multivariate Analysis, 130, 27–44.
Srivastava, M. S. (2005). Some tests concerning the covariance matrix in high dimensional data. Journal of the Japan Statistical Society, 35(2), 251–272.
HS.model <- '
visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9
'
fit <- cfa(HS.model, data = HolzingerSwineford1939)
lavTest(fit, test = "browne.residual.adf")
lavTest(fit, test = "peba4", output = "text")
lavTest(fit, test = "pols3", scaled_test = "RLS", output = "text")
# corrected adjusted test (Hayakawa, 2018), based on the RLS statistic
lavTest(fit, test = "mean.var.adjusted.corrected", scaled_test = "RLS",
output = "text")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.