Learn R Programming

lavaan (version 0.7-2)

lav_long_names: Deprecated functions with long names

Description

Functions that are deprecated following the adoption of shorter names in May 2026.

Usage

lav_matrix_duplication_ginv_pre_post(A = matrix(0, 0, 0))
lav_matrix_orthogonal_complement(A = matrix(0, 0, 0))
lav_func_gradient_complex(
                          func,
                          x,
                          h = .Machine$double.eps,
                          ...,
                          fallback.simple = TRUE)
lav_matrix_duplication_ginv_post(A = matrix(0, 0, 0))
lav_func_gradient_simple(
                         func,
                         x,
                         h = sqrt(.Machine$double.eps),
                         ...)
lav_matrix_vech_row_idx(n = 1L, diagonal = TRUE)
lav_matrix_vech_col_idx(n = 1L, diagonal = TRUE)
lav_matrix_antidiag_idx(n = 1L)
lav_matrix_duplication_pre_post(A = matrix(0, 0, 0))
lav_matrix_duplication_ginv_pre(A = matrix(0, 0, 0))
lav_matrix_commutation_pre_post(A = matrix(0, 0, 0))
lav_partable_unrestricted(
                          lavobject = NULL,
                          lavdata = NULL,
                          lavpta = NULL,
                          lavoptions = NULL,
                          lavsamplestats = NULL,
                          lavh1 = NULL,
                          sample.cov = NULL,
                          sample.mean = NULL,
                          sample.slopes = NULL,
                          sample.th = NULL,
                          sample.th.idx = NULL,
                          sample.cov.x = NULL,
                          sample.mean.x = NULL)
lav_partable_independence(
                          lavobject = NULL,
                          lavdata = NULL,
                          lavpta = NULL,
                          lavoptions = NULL,
                          lavsamplestats = NULL,
                          lavh1 = NULL,
                          sample.cov = NULL,
                          sample.mean = NULL,
                          sample.slopes = NULL,
                          sample.th = NULL,
                          sample.th.idx = NULL,
                          sample.cov.x = NULL,
                          sample.mean.x = NULL)
lav_matrix_vechru_idx(n = 1L, diagonal = TRUE)
lav_matrix_upper2full(x, diagonal = TRUE)
lav_matrix_lower2full(x, diagonal = TRUE)
lav_matrix_commutation_mn_pre(
                              A,
                              m = 1L,
                              n = 1L)
lav_samplestats_from_data(
                          lavdata = NULL,
                          lavoptions = NULL,
                          WLS.V = NULL,
                          NACOV = NULL)
lav_matrix_vechru_reverse(x, diagonal = TRUE)
lav_matrix_vechr_idx(n = 1L, diagonal = TRUE)
lav_matrix_vechu_idx(n = 1L, diagonal = TRUE)
lav_matrix_diagh_idx(n = 1L)
lav_partable_attributes(partable, pta = NULL)
lav_matrix_vechr_reverse(x, diagonal = TRUE)
lav_matrix_vechu_reverse(x, diagonal = TRUE)
lav_matrix_vech_idx(n = 1L, diagonal = TRUE)
lav_matrix_diag_idx(n = 1L)
lav_matrix_duplication_post(A = matrix(0, 0, 0))
lav_matrix_duplication_ginv(n = 1L)
lav_matrix_commutation_post(A = matrix(0, 0, 0))
lav_matrix_symmetric_sqrt(S = matrix(0, 0, 0))
lav_matrix_vech_reverse(x, diagonal = TRUE)
lav_matrix_duplication_pre(A = matrix(0, 0, 0))
lav_matrix_commutation_pre(A = matrix(0, 0, 0))
lav_partable_complete(partable = NULL, start = TRUE)
lav_matrix_vechru(S, diagonal = TRUE)
lav_partable_constraints_def(
                             partable,
                             con = NULL,
                             debug = FALSE,
                             txtOnly = FALSE,
                             warn = TRUE)
lav_partable_constraints_ceq(
                             partable,
                             con = NULL,
                             debug = FALSE,
                             txtOnly = FALSE)
lav_partable_constraints_ciq(
                             partable,
                             con = NULL,
                             debug = FALSE,
                             txtOnly = FALSE)
lav_partable_from_lm(
                     object,
                     est = FALSE,
                     label = FALSE,
                     as.data.frame. = FALSE)
lav_constraints_parse(
                      partable = NULL,
                      constraints = NULL,
                      theta = NULL,
                      debug = FALSE)
lav_matrix_vechr(S, diagonal = TRUE)
lav_matrix_vechu(S, diagonal = TRUE)
lav_matrix_bdiag(...)
lav_matrix_trace(..., check = TRUE)
lav_partable_labels(
                    partable,
                    blocks = c("group", "level"),
                    group.equal = "",
                    group.partial = "",
                    type = "user")
lav_matrix_vecr(A)
lav_matrix_vech(S, diagonal = TRUE)
lav_partable_merge(
                   pt1 = NULL,
                   pt2 = NULL,
                   remove.duplicated = FALSE,
                   fromLast = FALSE,
                   warn = TRUE)
lav_matrix_vec(A)
lav_matrix_duplication(n = 1L)
lav_matrix_commutation(m = 1L, n = 1L)
lav_matrix_cov(Y, Mu = NULL)
lav_partable_ndat(partable)
lav_partable_npar(partable)
lav_partable_add(partable = NULL, add = list())
lav_partable_df(partable)

Arguments

...

See argument ... in the corresponding function with shortened name.

A

See argument a in the corresponding function with shortened name.

add

See argument add in the corresponding function with shortened name.

as.data.frame.

See argument as_data_frame in the corresponding function with shortened name.

blocks

See argument blocks in the corresponding function with shortened name.

check

See argument check in the corresponding function with shortened name.

con

See argument con in the corresponding function with shortened name.

constraints

See argument constraints in the corresponding function with shortened name.

debug

See argument debug in the corresponding function with shortened name.

diagonal

See argument diagonal in the corresponding function with shortened name.

est

See argument est in the corresponding function with shortened name.

fallback.simple

See argument fallback_simple in the corresponding function with shortened name.

fromLast

See argument from_last in the corresponding function with shortened name.

func

See argument func in the corresponding function with shortened name.

group.equal

See argument group_equal in the corresponding function with shortened name.

group.partial

See argument group_partial in the corresponding function with shortened name.

h

See argument h in the corresponding function with shortened name.

label

See argument label in the corresponding function with shortened name.

lavdata

See argument lavdata in the corresponding function with shortened name.

lavh1

See argument lavh1 in the corresponding function with shortened name.

lavobject

See argument lavobject in the corresponding function with shortened name.

lavoptions

See argument lavoptions in the corresponding function with shortened name.

lavpta

See argument lavpta in the corresponding function with shortened name.

lavsamplestats

See argument lavsamplestats in the corresponding function with shortened name.

m

See argument m in the corresponding function with shortened name.

Mu

See argument mu in the corresponding function with shortened name.

n

See argument n in the corresponding function with shortened name.

NACOV

See argument nacov in the corresponding function with shortened name.

object

See argument object in the corresponding function with shortened name.

partable

See argument partable in the corresponding function with shortened name.

pt1

See argument pt1 in the corresponding function with shortened name.

pt2

See argument pt2 in the corresponding function with shortened name.

pta

See argument pta in the corresponding function with shortened name.

remove.duplicated

See argument remove_duplicated in the corresponding function with shortened name.

S

See argument s in the corresponding function with shortened name.

sample.cov

See argument sample_cov in the corresponding function with shortened name.

sample.cov.x

See argument sample_cov_x in the corresponding function with shortened name.

sample.mean

See argument sample_mean in the corresponding function with shortened name.

sample.mean.x

See argument sample_mean_x in the corresponding function with shortened name.

sample.slopes

See argument sample_slopes in the corresponding function with shortened name.

sample.th

See argument sample_th in the corresponding function with shortened name.

sample.th.idx

See argument sample_th_idx in the corresponding function with shortened name.

start

See argument start in the corresponding function with shortened name.

theta

See argument theta in the corresponding function with shortened name.

txtOnly

See argument txt_only in the corresponding function with shortened name.

type

See argument type in the corresponding function with shortened name.

warn

See argument warn in the corresponding function with shortened name.

WLS.V

See argument wls_v in the corresponding function with shortened name.

x

See argument x in the corresponding function with shortened name.

Y

See argument y in the corresponding function with shortened name.

Details

Function names are shortened by the following replacements:

_mvnorm

_mvn

_cluster

_cl

_missing

_mi

_matrix

_mat

_duplication

_dup

_commutation

_com

_information

_info

_samplestats

_samp

_satorra_bentler

_sb

_SatorraBentler

_sb

_yuan_bentler

_yb

_inverted

_inv

_estimate

_est

_symmetric

_sym

_lavaan_step

_step

_univariate

_uni

_fit_measures

_fit

_constraints

_con

_scores

_sc

_reverse

_rev

_vech_sigma

_sigma

_vechsigma

_sigma

_object_inspect

_inspect

_orthogonal

_ortho

_gradient

_grad

_partable

_pt