| lav_model | R Documentation |
Utility functions related to internal model representation (lavmodel)
# set/get free parameters
lav_model_set_parameters(lavmodel, x = NULL)
lav_model_get_parameters(lavmodel, glist = NULL, type = "free",
extra = TRUE, ...)
# compute model-implied statistics
lav_model_implied(lavmodel, glist = NULL, delta = TRUE, ...)
# compute standard errors
lav_model_vcov_se(lavmodel, lavpartable, vcov = NULL, boot = NULL,
mc = NULL, lavoptions = NULL, ...)
lavmodel |
An internal representation of a lavaan model. |
x |
Numeric. A vector containing the values of all the free model parameters. |
glist |
List. A list of model matrices, similar to the output of
|
type |
Character string. If |
extra |
Logical. If |
delta |
Logical. If |
lavpartable |
A parameter table. |
vcov |
Numeric matrix containing an estimate of the variance covariance matrix of the free model parameters. |
boot |
Numeric matrix containing the bootstrap based parameter estimates (in the columns) for each bootstrap sample (in the rows). |
mc |
Numeric matrix containing the Monte-Carlo based parameter estimates (in the columns) for each Monte-Carlo sample (in the rows). |
lavoptions |
A named list. The Options slot from a lavaan object. |
... |
To accept old argument names with dots or capitals. No other arguments are accepted. |
HS.model <- ' visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9 '
fit <- cfa(HS.model, data=HolzingerSwineford1939)
lavmodel <- fit@Model
est <- lav_model_get_parameters(lavmodel)
est
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.