A character string of converted lavaan model syntax.
Arguments
syntax
A character vector containing Mplus model syntax to be
converted to lavaan model syntax. Note that parsing Mplus syntax often
requires correct usage of newline characters. If syntax is a
vector of multiple strings, these will be joined with newlines prior
to conversion. Alternatively, \n characters can be included
inline in syntax.