The lavaan class represents a (fitted) latent variable
model. It contains a description of the model as specified by the user,
a summary of the data, an internal matrix representation, and if the model
was fitted, the fitting results.
Objects can be created via the
cfa, sem, growth or
lavaan functions.
version:The lavaan package version used to create this object
call:The function call as returned by match.call().
timing:The elapsed time (user+system) for various parts of the program as a list, including the total time.
Options:Named list of options that were provided by the user, or filled-in automatically.
ParTable:Named list describing the model parameters. Can be coerced to a data.frame. In the documentation, this is called the `parameter table'.
pta:Named list containing parameter table attributes.
Data:Object of internal class "Data": information
about the data.
SampleStats:Object of internal class "SampleStats": sample
statistics
Model:Object of internal class "Model": the
internal (matrix) representation of the model
Cache:List of objects that are computed only once and reused many times.
Fit:Object of internal class "Fit": the
results of fitting the model. No longer used.
boot:List. Results and information about the bootstrap.
optim:List. Information about the optimization.
loglik:List. Information about the loglikelihood of the model (if maximum likelihood was used).
implied:List. Model implied statistics.
vcov:List. Information about the variance matrix (vcov) of the model parameters.
test:List. Different test statistics.
h1:List. Information about the unrestricted h1 model (if available).
baseline:List. Information about a baseline model (often the independence model) (if available).
internal:List. For internal use only.
external:List. Empty slot to be used by add-on packages.
signature(object = "lavaan", type = "free"): Returns
the estimates of the parameters in the model as a named numeric vector.
If type="free", only the free parameters are returned.
If type="user", all parameters listed in the parameter table
are returned, including constrained and fixed parameters.
signature(object = "lavaan"): Returns the
implied moments of the model as a list with two elements (per group):
cov for the implied covariance matrix,
and mean for the implied mean
vector. If only the covariance matrix was analyzed, the implied mean
vector will be zero.
signature(object = "lavaan"): an alias for
fitted.values.
signature(object = "lavaan", type="raw"):
If type = "raw", this function returns the raw (= unscaled)
difference between the observed and the expected (model-implied) summary
statistics.
If type = "cor", or type = "cor.bollen", the observed and
model implied covariance matrices are first transformed to a correlation
matrix (using cov2cor()), before the residuals are computed.
If type = "cor.bentler", both the observed and model implied
covariance matrices are rescaled by dividing the elements by the square
roots of the corresponding variances of the observed covariance matrix.
If type="normalized", the residuals are divided by the square
root of the asymptotic variance of the corresponding summary statistic
(the variance estimate depends on the choice for the se argument).
Unfortunately, these normalized residuals are not entirely
correct, and this option is retained only for historical interest.
If type="standardized", the residuals are divided by the square
root of the asymptotic variance of these residuals. The resulting
standardized residuals can be interpreted as z-scores.
If type="standardized.mplus", the residuals are divided by the
square root of the asymptotic variance of these residuals. However, a
simplified formula is used (see the Mplus reference below) which often
results in negative estimates for the variances, resulting in many
NA values for the standardized residuals.
signature(object = "lavaan"): an alias
for residuals
signature(object = "lavaan", type = "free"): returns
the covariance matrix of the estimated parameters. If
type = "free" (the default), only the free parameters are
included. If type = "user" (or "joint"), the joint
covariance matrix of the free and the user-defined (:=)
parameters is returned; the parameter names are the same as those
used by coef().
signature(object = "lavaan"): compute
factor scores for all cases that are provided in the data frame. For
complete data only.
signature(object = "lavaan"): returns
model comparison statistics. This method is just a wrapper around
the function lavTestLRT.
If only a single argument (a fitted
model) is provided, this model is compared to the unrestricted
model. If two or more arguments (fitted models) are provided, the models
are compared in a sequential order. Test statistics are based on the
likelihood ratio test. For more details and
further options, see the lavTestLRT page.
signature(object = "lavaan", model, add, ...,
evaluate = TRUE): update a fitted lavaan object and evaluate it
(unless evaluate = FALSE). Note that we use the environment
that is stored within the lavaan object, which is not necessarily
the parent frame. The add argument is analogous to the one
described in the lavTestScore page, and can be used to
add parameters to the specified model rather than passing an entirely
new model argument.
signature(object = "lavaan"): returns the effective
number of observations used when fitting the model. In a multiple group
analysis, this is the sum of all observations per group.
signature(object = "lavaan"):
returns the log-likelihood of the fitted model, if maximum likelihood estimation
was used. The AIC and BIC
methods automatically work via logLik().
signature(object = "lavaan"): Print a short summary
of the model fit
signature(object = "lavaan", header = TRUE,
fit_measures = FALSE, residuals = FALSE,
estimates = TRUE, ci = FALSE, fmi = FALSE,
standardized = FALSE, std = standardized, std_nox = FALSE,
remove_system_eq = TRUE, remove_eq = TRUE, remove_ineq = TRUE,
remove_def = FALSE, remove_nonfree = FALSE, remove_step1 = TRUE,
remove_unused = TRUE, plabel = FALSE,
cov_std = TRUE, rsquare = FALSE,
baseline_model = NULL, h1_model = NULL,
fm_args = list(standard.test = "default", scaled.test = "default",
rmsea.ci.level = 0.90, rmsea.h0.closefit = 0.05,
rmsea.h0.notclosefit = 0.08, robust = TRUE, cat.nonpd = "na"),
modindices = FALSE, srmr_close_h0 = NULL,
nd = 3L, cutoff = 0.3, dot_cutoff = 0.1):
Print a nice summary of the model estimates.
If header = TRUE, the header section (including fit measures) is
printed.
If fit.measures = TRUE, additional fit measures are added to the
header section. fit.measures can also be a list, which allows one to set options
related to the fit measures. See fitMeasures
for more details.
If residuals = TRUE, a residuals section is added (the largest
residuals and the residual summary, printed as by
lavResiduals with output = "text"); the underlying
lavResiduals(object, output = "list") result is stored as the
residuals element of the summary object. residuals can also
be a list of arguments passed on to lavResiduals (for
example residuals = list(type = "raw", n.largest = 10)).
If both fit.measures = TRUE and residuals = TRUE and the
residual summary is the SRMR (the default), the SRMR is removed from the
fit measures section to avoid printing it twice.
If estimates = TRUE, print the parameter estimates section.
If ci = TRUE, add confidence intervals to the parameter estimates
section.
If fmi = TRUE, add the fmi (fraction of missing information)
column, if it is available.
If standardized = TRUE or a character vector, the standardized
solution is also printed (see lavParameterEstimates).
Note that SEs and
tests are still based on unstandardized estimates. Use
standardizedSolution to obtain SEs and test
statistics for standardized estimates.
The std.nox argument is deprecated; the standardized
argument allows "std.nox" solution to be specifically requested.
The standardized argument may also be a character vector of
(observed) variable names (for example c("x1", "x2")); only the
parameters involving these variables are then standardized, and the
result is shown in a Std.usr column. This generalizes
"std.nox", where the exogenous x variables are the ones
left unstandardized.
If remove_system_eq = TRUE, the system-generated equality
constraints (using plabels) are not shown.
If remove_eq = TRUE or remove_ineq = TRUE,
the user-specified (in)equality constraints are not shown.
If remove_def = TRUE, the user-specified parameter definitions are
not shown.
If remove_nonfree = TRUE, the nonfree parameters are not shown.
If remove_step1 = TRUE, the parameters of the measurement part
are not shown (only used when using sam().)
If remove_unused = TRUE, automatically added parameters that are
fixed to their default (0 or 1) values are removed.
If rsquare = TRUE, the R-Square values for the dependent variables
in the model are printed.
The fm.args list allows one to set options related to the fit
measures (see fitMeasures).
baseline.model and h1.model allow one to specify user-defined
baseline and/or h1 models for the fit measures.
If the model is an exploratory factor analysis (EFA) model, EFA related
information is printed automatically. The cutoff and
dot.cutoff arguments control how the factor loadings are displayed:
loadings whose absolute value is at or above cutoff are shown as
numbers; loadings whose absolute value falls between dot.cutoff
and cutoff are replaced by a dot; loadings whose absolute value is
below dot.cutoff are left blank.
If modindices = TRUE or modindices is a list,
modification indices are printed for all fixed parameters.
The argument nd determines the number of digits after the
decimal point to be printed (currently only in the parameter estimates
section.) Historically, nothing was returned, but since 0.6-12, a
list is returned of class lavaan.summary for which a print
function is available.
Yves Rosseel (2012). lavaan: An R Package for Structural Equation Modeling. Journal of Statistical Software, 48(2), 1-36. tools:::Rd_expr_doi("10.18637/jss.v048.i02")
Standardized Residuals in Mplus. Document retrieved from URL https://www.statmodel.com/download/StandardizedResiduals.pdf
cfa, sem,
fitMeasures, standardizedSolution,
lavParameterEstimates, lavInspect,
modindices
HS.model <- ' visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9 '
fit <- cfa(HS.model, data = HolzingerSwineford1939)
summary(fit, standardized = TRUE, fit.measures = TRUE, rsquare = TRUE)
fitted(fit)
coef(fit)
resid(fit, type = "normalized")
Run the code above in your browser using DataLab