estfun.lavaan(object, scaling = FALSE, remove.duplicated = TRUE)lavaan.TRUE, the scores are scaled to reflect the specific
objective function used by lavaan. If FALSE (the default), the
objective function is the loglikelihood function assuming multivariate
normality.TRUE, and all the equality constraints have
a simple form (eg. a == b), the unconstrained scores are post-multiplied with a
transformation matrix in order to remove the duplicated parameters.