The lavInspect() and lavTech() functions can be used to
inspect/extract information that is stored inside (or can be computed from) a
fitted lavaan object. Note: the (older) inspect() function is
now simply a shortcut for lavInspect() with default arguments.
lavInspect(object, what = "free", add_labels = TRUE, add_class = TRUE,
list_by_group = TRUE,
drop_list_single_group = TRUE, ...)lavTech(object, what = "free", add_labels = FALSE, add_class = FALSE,
list_by_group = FALSE,
drop_list_single_group = FALSE, ...)
inspect(object, what = "free", ...)
An object of class lavaan.
Character. What needs to be inspected/extracted? See Details for a
full list. Note: the what argument is not case-sensitive
(everything is converted to lower case.)
If TRUE, variable names are added to the vectors
and/or matrices.
If TRUE, vectors are given the `lavaan.vector' class;
matrices are given the `lavaan.matrix' class, and symmetric matrices are
given the `lavaan.matrix.symmetric' class. This only affects the way they
are printed on the screen.
Logical. Only used when the output are model matrices.
If TRUE, the model matrices are nested within groups. If FALSE,
a flattened list is returned containing all model matrices, with repeated
names for multiple groups.
If FALSE, the results are returned as
a list, where each element corresponds to a group (even if there is only
a single group). If TRUE, the list will be unlisted if there is
only a single group.
For inspect() additional arguments can be specified, not used by lavaan, but by other packages.
For the functions lavInspect() and lavTech() this argument is used to support old names of arguments.
The lavInspect() and lavTech() functions only differ in the way
they return the results. The lavInspect() function will prettify the
output by default, while the lavTech() will not attempt to prettify the
output by default. The (older) inspect() function is a simplified
version of lavInspect() with only the first two arguments.
Below is a list of possible values for the what argument, organized
in several sections:
Model matrices:
"free":A list of model matrices. The non-zero integers
represent the free parameters. The numbers themselves correspond
to the position of the free parameter in the parameter vector.
This determines the order of the model parameters in the output
of, for example, coef() and vcov().
"partable":A list of model matrices. The non-zero integers
represent both the fixed parameters (for example, factor loadings
fixed at 1.0) and the free parameters (ignoring any equality
constraints). They correspond to all entries (fixed or free)
in the parameter table. See parTable.
"se":A list of model matrices. The non-zero numbers
represent the standard errors for the free parameters in the model.
If two parameters are constrained to be equal, they will share the
same standard error.
Aliases: "std.err" and "standard.errors".
"se.std":A list of model matrices. The non-zero numbers
represent the standard errors for the (completely) standardized free
parameters in the model. Alias: "std.se".
"start":A list of model matrices. The values represent
the starting values for all model parameters.
Alias: "starting.values".
"est":A list of model matrices. The values represent
the estimated model parameters. Aliases:
"estimates", and "x".
"est.unrotated":A list of model matrices. The values
represent the estimated model parameters before rotation was applied.
Only relevant if rotation was used (for example in EFA); otherwise
this is identical to "est".
"dx.free":A list of model matrices. The values represent the gradient (first derivative) values of the model parameters. If two parameters are constrained to be equal, they will have the same gradient value.
"dx.all":A list of model matrices. The values represent
the first derivative with respect to all possible matrix elements.
Currently, this is only available when the estimator is "ML"
or "GLS".
"std":A list of model matrices. The values represent
the (completely) standardized model parameters (the variances of
both the observed and the latent variables are set to unity).
Aliases: "std.all", "standardized".
"std.lv":A list of model matrices. The values represent the standardized model parameters (only the variances of the latent variables are set to unity.)
"std.nox":A list of model matrices. The values represent the (completely) standardized model parameters (the variances of both the observed and the latent variables are set to unity; however, the variances of any observed exogenous variables are not set to unity; hence no-x.)
"mm.lambda":The estimated factor loading matrix (per
group), as extracted from the @GLIST slot.
Alias: "lambda".
"mm.delta":The estimated delta (scaling) matrix (per group),
as extracted from the @GLIST slot. Only available for
categorical data or when a correlation structure is used. (Note: this
is the delta model matrix, not the delta jacobian that is
returned by "delta".)
To extract a single model matrix (from the @GLIST slot), use the
"mm.*" options (for example "mm.lambda" for the factor loading
matrix). For backward compatibility, the (older) bare names are still accepted
as aliases.
Information about the data:
"data":A matrix containing the observed variables
that were used to fit the model. The matrix has no row or column
names. The columns correspond to the output of
lav_object_vnames(object), while the rows correspond to the
output of lavInspect(object, "case.idx").
"ordered":A character vector. The ordered variables.
"nobs":Numeric vector. The effective number of observations
in each group that were used in the analysis. If sampling weights were
provided, this is the (per group) sum of the weights, consistent with
the value returned by the nobs() method. Use "norig" to
obtain the number of rows in the data.
"norig":Integer vector. The original number of observations (rows in the data) in each group.
"ntotal":Numeric. The total effective number of observations
that were used in the analysis. If there is just a single group, this
is the same as the "nobs" option; if there are multiple groups,
this is the sum of the "nobs" numbers for each group. If sampling
weights were provided, this is the sum of the weights.
"case.idx":Integer vector. The case/observation numbers that were used in the analysis. In the case of multiple groups: a list of numbers.
"empty.idx":The case/observation numbers of those cases/observations that contained missing values only (at least for the observed variables that were included in the model). In the case of multiple groups: a list of numbers.
"th.idx":Integer vector. For categorical data, the index of the observed variable that each threshold belongs to. In the case of multiple groups: a list of integer vectors.
"patterns":A binary matrix. The rows of the matrix
are the missing data patterns where 1 and 0 denote non-missing
and missing values for the corresponding observed variables
respectively (or
TRUE and FALSE if lavTech() is used.)
If the data is complete (no missing values), there will be only
a single pattern. In the case of multiple groups: a list of
pattern matrices.
"coverage":A symmetric matrix in which each element contains the proportion of jointly observed data points for the corresponding pair of observed variables. In the case of multiple groups: a list of coverage matrices.
"group":A character string. The group variable in the data.frame (if any).
"ngroups":Integer. The number of groups.
"group.label":A character vector. The group labels.
"level.label":A character vector. The level labels.
"cluster":A character vector. The cluster variable(s) in the data.frame (if any).
"nlevels":Integer. The number of levels.
"nclusters":Integer. The number of clusters that were used in the analysis.
"ncluster.size":Integer. The number of different cluster sizes.
"cluster.size":Integer vector. The number of observations within each cluster. For multigroup multilevel models, a list of integer vectors, indicating cluster sizes within each group.
"cluster.id":Integer vector. The cluster IDs identifying the clusters. For multigroup multilevel models, a list of integer vectors, indicating cluster IDs within each group.
"cluster.idx":Integer vector. The cluster index for each observation. The cluster index ranges from 1 to the number of clusters. For multigroup multilevel models, a list of integer vectors, indicating cluster indices within each group.
"cluster.label":Integer vector. The cluster ID for each observation. For multigroup multilevel models, a list of integer vectors, indicating the cluster ID for each observation within each group.
"cluster.sizes":Integer vector. The different cluster sizes that were used in the analysis. For multigroup multilevel models, a list of integer vectors, indicating the different cluster sizes within each group.
"average.cluster.size":Integer. The average cluster
size (using the formula
s = (N^2 - sum(cluster.size^2)) / (N*(nclusters - 1L))).
For multigroup multilevel
models, a list containing the average cluster size per group.
Observed sample statistics:
"sampstat":Observed sample statistics. Aliases:
"obs", "observed", "samp", "sample",
"samplestatistics". Since
0.6-3, we always check if an h1 slot is available (the estimates
for the unrestricted model); if present, we extract the sample
statistics from this slot. This implies that if the variables are
continuous and missing = "ml" (or "fiml"), we
return the covariance matrix (and mean vector) as computed by
the EM algorithm under the unrestricted (h1) model. If the h1 slot
is not present (for example, because the model was fitted with
h1 = FALSE), we return the sample statistics from the
SampleStats slot. In that case, pairwise deletion is used for the
elements of the covariance matrix (or correlation matrix), and
listwise deletion for all univariate statistics (means, intercepts,
and thresholds).
"sampstat.std":Standardized observed sample statistics.
The covariance matrix is rescaled to a correlation matrix. Aliases:
"obs.std", "observed.std", "samp.std",
"sample.std", "samplestatistics.std".
"sampstat.h1":Deprecated. Do not use any longer.
"wls.obs":The observed sample statistics (covariance elements, intercepts/thresholds, etc.) in a single vector.
"wls.v":The weight vector as used in weighted least squares estimation.
"gamma":N times the asymptotic variance matrix of the
sample statistics. Alias: "sampstat.nacov".
Model features:
"meanstructure":Logical. TRUE if a meanstructure
was included in the model.
"categorical":Logical. TRUE if categorical endogenous
variables were part of the model.
"fixed.x":Logical. TRUE if the exogenous x-covariates
are treated as fixed.
"parameterization":Character. Either "delta" or
"theta".
Model-implied sample statistics:
"implied":The model-implied summary statistics.
Alias: "fitted", "expected", "exp".
"resid":The difference between observed and model-implied
summary statistics.
Alias: "residuals", "residual", "res".
"cov.lv":The model-implied variance-covariance matrix
of the latent variables. Alias: "veta" [for V(eta)].
"cor.lv":The model-implied correlation matrix of the latent variables.
"mean.lv":The model-implied mean vector of the latent
variables. Alias: "eeta" [for E(eta)].
"cov.ov":The model-implied variance-covariance matrix
of the observed variables.
Aliases: "sigma", "sigma.hat".
"cor.ov":The model-implied correlation matrix of the observed variables.
"mean.ov":The model-implied mean vector of the observed
variables. Aliases: "mu", "mu.hat".
"cov.all":The model-implied variance-covariance matrix of both the observed and latent variables.
"cor.all":The model-implied correlation matrix of both the observed and latent variables.
"th":The model-implied thresholds.
Alias: "thresholds".
"mm.theta":The (residual) variance-covariance
matrix of the observed variables (the theta model matrix).
Aliases: "theta", "theta.cov".
"theta.cor":The (residual) variance-covariance matrix of the observed variables, expressed in correlation metric.
"wls.est":The model-implied sample statistics (covariance elements, intercepts/thresholds, etc.) in a single vector.
"vy":The model-implied unconditional variances of the observed variables.
"rsquare":The R-square value for all endogenous variables.
Aliases: "r-square", "r2".
"fs_determinacy":The factor determinacies (based on regression factor scores). They represent the (estimated) correlation between the factor scores and the latent variable scores.
"fs.reliability":The factor reliabilities (based on regression factor scores). They are the square of the factor determinacies.
"fs_determinacy_Bartlett":The factor determinacies (based on Bartlett factor scores). They represent the (estimated) correlation between the factor scores and the latent variable scores.
"fs_reliability_bartlett":The factor reliabilities (based on Bartlett factor scores). They are the square of the factor determinacies.
"icc":The intraclass correlation coefficients for clustered data with multilevel models. Computed from the model-implied (H1) within-group and between-group covariance matrices. Only available for models with clustered data and multiple levels.
"ranef":The random effects (empirical Bayes predictions of the cluster-level latent variables). Only available for clustered data (in the long format) with multiple levels.
Diagnostics:
"mdist2.fs":The squared Mahalanobis distances for the (Bartlett) factor scores.
"mdist.fs":The Mahalanobis distances for the (Bartlett) factor scores.
"mdist2.resid":The squared Mahalanobis distances for the (Bartlett-based) casewise residuals.
"mdist.resid":The Mahalanobis distances for the (Bartlett-based) casewise residuals.
If (some of) the data is ordered categorical, the Mahalanobis distances are
generalized as in Mansolf and Reise (2017): each distance is replaced by its
expected value over the region of the (multivariate normally distributed)
latent response vector that is consistent with the observed response pattern,
approximated by Monte Carlo integration (set.seed() can be used for
reproducibility). Observed continuous variables are conditioned on, and
missing values are integrated out. Note that in this case
"mdist.fs"/"mdist.resid" return the expected distance
\(E[d]\) (the person-fit indices \(d_f^*\) and \(d_r^*\) of Mansolf
and Reise), while "mdist2.fs"/"mdist2.resid" return the
expected squared distance \(E[d^2]\), which is not the square of the
former.
Optimizer information:
"converged":Logical. TRUE if the optimizer has
converged; FALSE otherwise.
"iterations":Integer. The number of iterations used by the optimizer.
"optim":List. All available information regarding the optimization results.
"npar":Integer. Number of free parameters (ignoring constraints).
Gradient, Hessian, observed, expected and first.order information matrices:
"gradient":Numeric vector containing the first derivatives of the discrepancy function with respect to the (free) model parameters.
"gradient.logl":Numeric vector containing the first derivatives of the loglikelihood with respect to the (free) model parameters.
"optim.gradient":Numeric vector containing the first derivatives of the objective function (as seen by the optimizer) with respect to the (free) model parameters.
"hessian":Matrix containing the second derivatives of the discrepancy function with respect to the (free) model parameters.
"information":Matrix containing either the observed or the expected information matrix (depending on the information option of the fitted model). This is unit-information, not total-information.
"information.expected":Matrix containing the expected information matrix for the free model parameters.
"information.observed":Matrix containing the observed information matrix for the free model parameters.
"information.first.order":Matrix containing the first.order
information matrix for the free model parameters. This is the
outer product of the gradient elements (the first derivative of
the discrepancy function with respect to the (free) model parameters).
Alias: "first.order".
"augmented.information":Matrix containing either the observed or the expected augmented (or bordered) information matrix (depending on the information option of the fitted model). Only relevant if constraints have been used in the model.
"augmented.information.expected":Matrix containing the expected augmented (or bordered) information matrix. Only relevant if constraints have been used in the model.
"augmented.information.observed":Matrix containing the observed augmented (or bordered) information matrix. Only relevant if constraints have been used in the model.
"augmented.information.first.order":Matrix containing the first.order augmented (or bordered) information matrix. Only relevant if constraints have been used in the model.
"inverted.information":Matrix containing either the observed or the expected inverted information matrix (depending on the information option of the fitted model).
"inverted.information.expected":Matrix containing the inverted expected information matrix for the free model parameters.
"inverted.information.observed":Matrix containing the inverted observed information matrix for the free model parameters.
"inverted.information.first.order":Matrix containing the inverted first.order information matrix for the free model parameters.
"h1.information":Matrix containing either the observed, expected or first.order information matrix (depending on the information option of the fitted model) of the unrestricted h1 model. This is unit-information, not total-information.
"h1.information.expected":Matrix containing the expected information matrix for the unrestricted h1 model.
"h1.information.observed":Matrix containing the observed information matrix for the unrestricted h1 model.
"h1.information.first.order":Matrix containing the
first.order information matrix for the unrestricted h1 model.
Alias: "h1.first.order".
Variance covariance matrix of the model parameters:
"vcov":Matrix containing the variance covariance matrix of the estimated model parameters.
"vcov.std.all":Matrix containing the variance covariance matrix of the standardized estimated model parameters. Standardization is done with respect to both observed and latent variables.
"vcov.std.lv":Matrix containing the variance covariance matrix of the standardized estimated model parameters. Standardization is done with respect to the latent variables only.
"vcov.std.nox":Matrix containing the variance covariance matrix of the standardized estimated model parameters. Standardization is done with respect to both observed and latent variables, but ignoring any exogenous observed covariates.
"vcov.def":Matrix containing the variance covariance matrix of the user-defined (using the := operator) parameters.
"vcov.def.std.all":Matrix containing the variance covariance matrix of the standardized user-defined parameters. Standardization is done with respect to both observed and latent variables.
"vcov.def.std.lv":Matrix containing the variance covariance matrix of the standardized user-defined parameters. Standardization is done with respect to the latent variables only.
"vcov.def.std.nox":Matrix containing the variance covariance matrix of the standardized user-defined parameters. Standardization is done with respect to both observed and latent variables, but ignoring any exogenous observed covariates.
"vcov.def.joint":Matrix containing the joint variance covariance matrix of both the estimated model parameters and the defined (using the := operator) parameters.
"vcov.def.joint.std.all":Matrix containing the joint variance covariance matrix of both the standardized model parameters and the user-defined parameters. Standardization is done with respect to both observed and latent variables.
"vcov.def.joint.std.lv":Matrix containing the joint variance covariance matrix of both the standardized model parameters and the user-defined parameters. Standardization is done with respect to the latent variables only.
"vcov.def.joint.std.nox":Matrix containing the joint variance covariance matrix of both the standardized model parameters and the user-defined parameters. Standardization is done with respect to both observed and latent variables, but ignoring any exogenous observed covariates.
Miscellaneous:
"coef.boot":Matrix containing estimated model parameters for each bootstrap sample. Only relevant when bootstrapping was used.
"monte.carlo":Matrix containing the Monte Carlo draws of the
model parameters, as used for the Monte Carlo confidence intervals of
defined parameters (Preacher & Selig, 2012). Only relevant when these
draws were requested. Aliases: "mc", "mc.coef",
"coef.mc".
"UGamma":Matrix containing the product of 'U' and 'Gamma' matrices as used by the Satorra-Bentler correction. The trace of this matrix, divided by the degrees of freedom, gives the scaling factor.
"UfromUGamma":Matrix containing the 'U' matrix
as used by the Satorra-Bentler correction. Alias: "U".
"delta":The delta matrix (per group): the Jacobian of the
model-implied summary statistics (the rows: means, (co)variances,
thresholds, ...) with respect to the free model parameters (the
columns). This is the matrix used in the delta method. (Note: this is
the delta Jacobian, not the delta model matrix that is returned
by "mm.delta".) In the case of multiple groups: a list of
matrices.
"delta.rownames":The row names of the delta matrix (see
"delta"): the labels of the model-implied summary statistics.
In the case of multiple groups: a list of character vectors.
"list":The parameter table. The same output as given
by parTable().
"fit":The fit measures. Aliases: "fitmeasures",
"fit.measures", "fit.indices". The same output as
given by fitMeasures().
"mi":The modification indices. Alias: "modindices",
"modification.indices". The same output as given
by modindices().
"loglik.casewise":Vector containing the casewise
loglikelihood contributions. Only available if estimator = "ML".
"options":List. The option list.
"call":List. The call as returned by match.call, coerced to a list.
"timing":List. The timing (in milliseconds) of various lavaan subprocedures.
"test":List. All available information regarding the (goodness-of-fit) test statistic(s).
"baseline.test":List. All available information regarding the (goodness-of-fit) test statistic(s) of the baseline model.
"baseline.partable":Data.frame. The parameter table of the (internal) baseline model.
"post.check":Post-fitting check if the solution is
admissible. A warning is raised if negative variances are found, or if
either lavInspect(fit, "cov.lv") or
lavInspect(fit, "theta") return a non-positive definite matrix.
"zero.cell.tables":List. List of bivariate frequency tables where at least one cell is empty.
"iv":Data.frame. One row per (transformed) equation, with
the (model-implied) instrumental variables that were used for each
equation. Columns are lhs, rhs, lhs.new,
rhs.new, type, and instruments. Only available
when estimator = "IV". Aliases: "ivs", "miiv",
"miivs", "instr", "instruments". In the case of
multiple groups: a list of data.frames.
"eqs":List. The (internal) list of equations that was used
for the (MI)IV-based estimation, including the instruments, the
coefficients, and the Sargan test per equation. Only available when
estimator = "IV".
"sargan":Data.frame. The per-equation overidentification
tests, for each overidentified equation. Columns are
lhs, rhs, df, sargan.stat,
sargan.pval, browne.stat, and browne.pval. The sargan.* columns are the classical
Sargan test (assumes normality; the p-value is NA for
categorical data, where it is not valid); the browne.* columns
are a robust residual-based test computed with the distribution-free
(ADF) ACOV for continuous data or the polychoric ACOV for categorical
data. "hansen" is an alias. Only available when
estimator = "IV". In the case of multiple groups: a list of
data.frames.
"sam.struc.fit.object":The (internal) step-2 structural
model of a model fitted with sam using a local
sam.method ("local", "fsr" or "cfsr"):
a lavaan object, fitted to the estimated latent (co)variances (and
means) of step 1. fitMeasures(), lavResiduals() and
modindices() operate on this object when they are called with
the sam object itself. "sam.struc" is an alias.
"version":The lavaan version number that was used to construct the fitted lavaan object.
lavaan, estimator_iv
# fit model
HS.model <- ' visual =~ x1 + x2 + x3
textual =~ x4 + x5 + x6
speed =~ x7 + x8 + x9 '
fit <- cfa(HS.model, data = HolzingerSwineford1939, group = "school")
# extract information
lavInspect(fit, "sampstat")
lavTech(fit, "sampstat")
Run the code above in your browser using DataLab