The constraints are specified using the "==" operator. Both
the left-hand side and the right-hand side of the equality can contain
a linear combination of model parameters, or a constant (like zero).
The model parameters must be specified by their user-specified labels.
Names of defined parameters (using the ":=" operator) can be
included too.
The test statistic is based on the variance-covariance matrix of the
estimated parameters (vcov) of the fitted object. Therefore, if
robust standard errors were requested for the fitted object (e.g.,
se = "robust.sem" or se = "robust.huber.white"), the main
test statistic is already the generalized (‘robust’) Wald test
described in Satorra (2000). In that case (or when a scaled test
statistic was requested, so that the ingredients for a sandwich-type
covariance matrix are available), additional versions of the Wald
test statistic are computed as well: the standard (normal-theory)
statistic (stat.standard), a mean-scaled statistic
(stat.scaled), a mean-and-variance adjusted statistic with
fractional degrees of freedom (stat.adjusted), and the
generalized statistic (stat.robust); see Satorra (2000).