Functions that are deprecated following the adoption of shorter names in May 2026.
lav_matrix_duplication_ginv_pre_post(A = matrix(0, 0, 0))
lav_matrix_orthogonal_complement(A = matrix(0, 0, 0))
lav_func_gradient_complex(
func,
x,
h = .Machine$double.eps,
...,
fallback.simple = TRUE)
lav_matrix_duplication_ginv_post(A = matrix(0, 0, 0))
lav_func_gradient_simple(
func,
x,
h = sqrt(.Machine$double.eps),
...)
lav_matrix_vech_row_idx(n = 1L, diagonal = TRUE)
lav_matrix_vech_col_idx(n = 1L, diagonal = TRUE)
lav_matrix_antidiag_idx(n = 1L)
lav_matrix_duplication_pre_post(A = matrix(0, 0, 0))
lav_matrix_duplication_ginv_pre(A = matrix(0, 0, 0))
lav_matrix_commutation_pre_post(A = matrix(0, 0, 0))
lav_partable_unrestricted(
lavobject = NULL,
lavdata = NULL,
lavpta = NULL,
lavoptions = NULL,
lavsamplestats = NULL,
lavh1 = NULL,
sample.cov = NULL,
sample.mean = NULL,
sample.slopes = NULL,
sample.th = NULL,
sample.th.idx = NULL,
sample.cov.x = NULL,
sample.mean.x = NULL)
lav_partable_independence(
lavobject = NULL,
lavdata = NULL,
lavpta = NULL,
lavoptions = NULL,
lavsamplestats = NULL,
lavh1 = NULL,
sample.cov = NULL,
sample.mean = NULL,
sample.slopes = NULL,
sample.th = NULL,
sample.th.idx = NULL,
sample.cov.x = NULL,
sample.mean.x = NULL)
lav_matrix_vechru_idx(n = 1L, diagonal = TRUE)
lav_matrix_upper2full(x, diagonal = TRUE)
lav_matrix_lower2full(x, diagonal = TRUE)
lav_matrix_commutation_mn_pre(
A,
m = 1L,
n = 1L)
lav_samplestats_from_data(
lavdata = NULL,
lavoptions = NULL,
WLS.V = NULL,
NACOV = NULL)
lav_matrix_vechru_reverse(x, diagonal = TRUE)
lav_matrix_vechr_idx(n = 1L, diagonal = TRUE)
lav_matrix_vechu_idx(n = 1L, diagonal = TRUE)
lav_matrix_diagh_idx(n = 1L)
lav_partable_attributes(partable, pta = NULL)
lav_matrix_vechr_reverse(x, diagonal = TRUE)
lav_matrix_vechu_reverse(x, diagonal = TRUE)
lav_matrix_vech_idx(n = 1L, diagonal = TRUE)
lav_matrix_diag_idx(n = 1L)
lav_matrix_duplication_post(A = matrix(0, 0, 0))
lav_matrix_duplication_ginv(n = 1L)
lav_matrix_commutation_post(A = matrix(0, 0, 0))
lav_matrix_symmetric_sqrt(S = matrix(0, 0, 0))
lav_matrix_vech_reverse(x, diagonal = TRUE)
lav_matrix_duplication_pre(A = matrix(0, 0, 0))
lav_matrix_commutation_pre(A = matrix(0, 0, 0))
lav_partable_complete(partable = NULL, start = TRUE)
lav_matrix_vechru(S, diagonal = TRUE)
lav_partable_constraints_def(
partable,
con = NULL,
debug = FALSE,
txtOnly = FALSE,
warn = TRUE)
lav_partable_constraints_ceq(
partable,
con = NULL,
debug = FALSE,
txtOnly = FALSE)
lav_partable_constraints_ciq(
partable,
con = NULL,
debug = FALSE,
txtOnly = FALSE)
lav_partable_from_lm(
object,
est = FALSE,
label = FALSE,
as.data.frame. = FALSE)
lav_constraints_parse(
partable = NULL,
constraints = NULL,
theta = NULL,
debug = FALSE)
lav_matrix_vechr(S, diagonal = TRUE)
lav_matrix_vechu(S, diagonal = TRUE)
lav_matrix_bdiag(...)
lav_matrix_trace(..., check = TRUE)
lav_partable_labels(
partable,
blocks = c("group", "level"),
group.equal = "",
group.partial = "",
type = "user")
lav_matrix_vecr(A)
lav_matrix_vech(S, diagonal = TRUE)
lav_partable_merge(
pt1 = NULL,
pt2 = NULL,
remove.duplicated = FALSE,
fromLast = FALSE,
warn = TRUE)
lav_matrix_vec(A)
lav_matrix_duplication(n = 1L)
lav_matrix_commutation(m = 1L, n = 1L)
lav_matrix_cov(Y, Mu = NULL)
lav_partable_ndat(partable)
lav_partable_npar(partable)
lav_partable_add(partable = NULL, add = list())
lav_partable_df(partable)See argument ... in the corresponding function with shortened name.
See argument a in the corresponding function with shortened name.
See argument add in the corresponding function with shortened name.
See argument as_data_frame in the corresponding function with shortened name.
See argument blocks in the corresponding function with shortened name.
See argument check in the corresponding function with shortened name.
See argument con in the corresponding function with shortened name.
See argument constraints in the corresponding function with shortened name.
See argument debug in the corresponding function with shortened name.
See argument diagonal in the corresponding function with shortened name.
See argument est in the corresponding function with shortened name.
See argument fallback_simple in the corresponding function with shortened name.
See argument from_last in the corresponding function with shortened name.
See argument func in the corresponding function with shortened name.
See argument group_equal in the corresponding function with shortened name.
See argument group_partial in the corresponding function with shortened name.
See argument h in the corresponding function with shortened name.
See argument label in the corresponding function with shortened name.
See argument lavdata in the corresponding function with shortened name.
See argument lavh1 in the corresponding function with shortened name.
See argument lavobject in the corresponding function with shortened name.
See argument lavoptions in the corresponding function with shortened name.
See argument lavpta in the corresponding function with shortened name.
See argument lavsamplestats in the corresponding function with shortened name.
See argument m in the corresponding function with shortened name.
See argument mu in the corresponding function with shortened name.
See argument n in the corresponding function with shortened name.
See argument nacov in the corresponding function with shortened name.
See argument object in the corresponding function with shortened name.
See argument partable in the corresponding function with shortened name.
See argument pt1 in the corresponding function with shortened name.
See argument pt2 in the corresponding function with shortened name.
See argument pta in the corresponding function with shortened name.
See argument remove_duplicated in the corresponding function with shortened name.
See argument s in the corresponding function with shortened name.
See argument sample_cov in the corresponding function with shortened name.
See argument sample_cov_x in the corresponding function with shortened name.
See argument sample_mean in the corresponding function with shortened name.
See argument sample_mean_x in the corresponding function with shortened name.
See argument sample_slopes in the corresponding function with shortened name.
See argument sample_th in the corresponding function with shortened name.
See argument sample_th_idx in the corresponding function with shortened name.
See argument start in the corresponding function with shortened name.
See argument theta in the corresponding function with shortened name.
See argument txt_only in the corresponding function with shortened name.
See argument type in the corresponding function with shortened name.
See argument warn in the corresponding function with shortened name.
See argument wls_v in the corresponding function with shortened name.
See argument x in the corresponding function with shortened name.
See argument y in the corresponding function with shortened name.
Function names are shortened by the following replacements:
_mvn
_cl
_mi
_mat
_dup
_com
_info
_samp
_sb
_sb
_yb
_inv
_est
_sym
_step
_uni
_fit
_con
_sc
_rev
_sigma
_sigma
_inspect
_ortho
_grad
_pt