Creates the code to make a diagram in tikz.
lav_plotinfo_tikzcode(plotinfo,
outfile = "",
cex = 1.3,
sloped.labels = TRUE,
standalone = FALSE,
mlovcolors = c("lightgreen", "lightblue"),
lightness = 1,
italic = TRUE,
auto.subscript = TRUE
)NULL, invisible
A plotinfo structure as returned from lav_plotinfo_positions.
A connection or a character string, the file to store the code.
Minimum distance between nodes in cm.
logical, sloped labels for the edges.
logical, add code to make teX file standalone?
Array of two colors for distinguishing ov nodes with same name between the levels in a multilevel model.
A scalar factor to modify the distances between nodes.
Are labels to be in italic font? If FALSE the labels will be shown in mathrm font.
Logical, see lav_label_code.
lav_plotinfo_positions