Learn R Programming

lavaan (version 0.7-2)

lav_plotinfo_tikzcode: Creates code to show a diagram in tikz format

Description

Creates the code to make a diagram in tikz.

Usage

lav_plotinfo_tikzcode(plotinfo,
                      outfile = "",
                      cex = 1.3,
                      sloped_labels = TRUE,
                      standalone = FALSE,
                      mlovcolors = c("lightgreen", "lightblue"),
                      lightness = 1,
                      italic = TRUE,
                      auto_subscript = TRUE
                     )

Value

NULL, invisible

Arguments

plotinfo

A plotinfo structure as returned from lav_plotinfo_positions.

outfile

A connection or a character string, the file to store the code.

cex

Minimum distance between nodes in cm.

sloped_labels

logical, sloped labels for the edges.

standalone

logical, should code be added to make the TeX file standalone?

mlovcolors

Array of two colors for distinguishing ov nodes with the same name across the levels of a multilevel model.

lightness

A scalar factor to modify the distances between nodes.

italic

Should labels be in an italic font? If FALSE, the labels are shown in mathrm font.

auto_subscript

Logical, see lav_label_code.

See Also

lav_plotinfo_positions