Creates the code to make a diagram in tikz.
lav_plotinfo_tikzcode(plotinfo,
outfile = "",
cex = 1.3,
sloped_labels = TRUE,
standalone = FALSE,
mlovcolors = c("lightgreen", "lightblue"),
lightness = 1,
italic = TRUE,
auto_subscript = TRUE
)NULL, invisible
A plotinfo structure as returned from lav_plotinfo_positions.
A connection or a character string, the file to store the code.
Minimum distance between nodes in cm.
logical, sloped labels for the edges.
logical, should code be added to make the TeX file standalone?
Array of two colors for distinguishing ov nodes with the same name across the levels of a multilevel model.
A scalar factor to modify the distances between nodes.
Should labels be in an italic font? If FALSE, the labels are shown in mathrm font.
Logical, see lav_label_code.
lav_plotinfo_positions