Deprecated functions in lavaan.
The functions listed in the first column below are deprecated; calls to them should be replaced by calls to the corresponding function in the second column.
| # bootstrapLavaan | lavBootstrap |
| char2num | lav_char2num |
| cor2cov | lav_cor2cov |
| getCov | lav_getcov |
| inspectSampleCov | lavInspectSampleCov |
| # lavaanNames | lavNames |
| mplus2lavaan.modelSyntax | lav_mplus_syntax_model |
| mplus2lavaan | lav_Mplus_lavaan |
| parameterestimates | lavParameterEstimates |
| # simulateData | lavSimulateData |