Learn R Programming

lavaan (version 0.7-2)

standardizedSolution: Standardized Solution

Description

Standardized solution of a latent variable model.

Usage

standardizedSolution(object, type = "std.all", se = TRUE, zstat = TRUE,
                     pvalue = TRUE, ci = TRUE, level = 0.95,
                     boot_ci_type = "perc", cov_std = TRUE,
                     remove_eq = TRUE, remove_ineq = TRUE, remove_def = FALSE,
                     remove_aux = TRUE,
                     partable = NULL, glist = NULL, est = NULL,
                     output = "data.frame", ...)

Value

A data.frame containing standardized model parameters.

If the model was fitted with se = "bootstrap" (and the bootstrap draws are available), the standardized estimates in the bootstrap samples are stored as the "boot_std" attribute of the returned data.frame (a matrix with one row per bootstrap draw and one column per row of the returned solution). These can be retrieved with

attr(x, "boot_std"), analogous to

lavInspect(object, "coef.boot") for the unstandardized solution.

In addition, if boot_ci_type = "bca", the empirical-influence design matrix used to compute the acceleration constant is stored as the

"design" attribute (retrieve with attr(x, "design")).

Arguments

object

An object of class lavaan.

type

If "std.lv", the standardized estimates are based on the variances of the (continuous) latent variables only. If "std.all", the standardized estimates are based on the variances of both (continuous) observed and latent variables. If "std.nox", the standardized estimates are based on the variances of both (continuous) observed and latent variables, but not the variances of exogenous covariates. Note that "std.nox" only differs from "std.all" if fixed.x = TRUE; if fixed.x = FALSE, the exogenous covariates are treated as random variables (and standardized) just like any other variable, and a warning is issued. Alternatively, type may be a vector of (observed) variable names (for example type = c("x1", "x2")); in that case only the parameters involving these variables are standardized (the other observed variables are left unstandardized). This is a generalization of "std.nox", where the (observed) exogenous x variables are the ones left unstandardized.

se

Logical. If TRUE, standard errors for the standardized parameters will be computed, together with a z-statistic and a p-value.

zstat

Logical. If TRUE, an extra column is added containing the so-called z-statistic, which is simply the value of the estimate divided by its standard error.

pvalue

Logical. If TRUE, an extra column is added containing the pvalues corresponding to the z-statistic, evaluated under a standard normal distribution.

ci

If TRUE, confidence intervals are added to the output.

level

The confidence level required.

boot_ci_type

Character. Only used if the model was fitted with se = "bootstrap". In that case, bootstrap standard errors and bootstrap confidence intervals are computed for the standardized parameters (by re-standardizing each bootstrap draw), and this argument selects the type of bootstrap confidence interval, exactly as in parameterEstimates: "norm", "basic", "perc" (the default), "bca.simple" or "bca".

cov_std

Logical. If TRUE, the (residual) observed covariances are scaled by the square root of the `Theta' diagonal elements, and the (residual) latent covariances are scaled by the square root of the `Psi' diagonal elements. If FALSE, the (residual) observed covariances are scaled by the square root of the diagonal elements of the observed model-implied covariance matrix (Sigma), and the (residual) latent covariances are scaled by the square root of diagonal elements of the model-implied covariance matrix of the latent variables.

remove_eq

Logical. If TRUE, filter the output by removing all rows containing equality constraints, if any.

remove_ineq

Logical. If TRUE, filter the output by removing all rows containing inequality constraints, if any.

remove_def

Logical. If TRUE, filter the output by removing all rows containing parameter definitions, if any.

remove_aux

Logical. If TRUE (the default), filter the output by removing all rows corresponding to auxiliary (aux=) variables added to the model as saturated correlates (only relevant when missing = "ml" and the aux= argument was used).

glist

List of model matrices. If provided, they will be used instead of the GLIST inside the object@Model slot. Only works if the est argument is also provided. See Note.

est

Numeric. Parameter values (as in the `est' column of a parameter table). If provided, they will be used instead of the parameters that can be extracted from object. Only works if the glist argument is also provided. See Note.

partable

A custom list or data.frame in which to store the standardized parameter values. If provided, it will be used instead of the parameter table inside the object@ParTable slot.

output

Character. If "data.frame", the parameter table is displayed as a standard (albeit lavaan-formatted) data.frame. If "text" (or alias "pretty"), the parameter table is prettified and displayed with subsections (as used by the summary function).

...

To support old argument names.

Details

The standardized estimates are functions of the (unstandardized) free parameters and of (a subset of) the model-implied (co)variances used for scaling. The standard errors reported by standardizedSolution are therefore standard errors for the standardized parameters, and they will in general differ from the standard errors of the unstandardized parameters reported by parameterEstimates (or in the summary() output). They are also not the same as the standard errors that would be obtained by simply rescaling the unstandardized standard errors.

How the standard errors are computed depends on how the model was originally fitted (in particular on the se= argument of lavaan, cfa, sem, ...):

  • By default (se = "standard", "robust.sem", "robust.huber.white", ...), the standard errors are obtained with the delta method: the Jacobian of the standardization function is computed (numerically) and combined with the variance-covariance matrix of the (unstandardized) parameter estimates. Any robustness present in that variance-covariance matrix (for example robust or sandwich-type standard errors) is automatically propagated to the standardized solution.

  • If the model was fitted with se = "bootstrap" (and the bootstrap draws are available), bootstrap standard errors and bootstrap confidence intervals are reported instead. These are obtained by re-standardizing each bootstrap draw and computing the standard deviation (for the standard error) and the requested interval type (see boot_ci_type) of the resulting standardized values. Note that, as in parameterEstimates, the p-value is still computed by referring the z-statistic (standardized estimate divided by its bootstrap standard error) to a standard normal distribution.

There is no separate argument to choose the type of standard error within standardizedSolution: the type always follows the se= setting that was used when the model was fitted. To obtain, say, robust or bootstrap standard errors for the standardized solution, refit the model with the corresponding se= argument.

Examples

Run this code
HS.model <- ' visual  =~ x1 + x2 + x3
              textual =~ x4 + x5 + x6
              speed   =~ x7 + x8 + x9 '

fit <- cfa(HS.model, data=HolzingerSwineford1939)
standardizedSolution(fit)

Run the code above in your browser using DataLab